@@ -1,7 +1,8 @@
-package Zonemaster::NSArray v1.0.0;
+package Zonemaster::NSArray v1.0.1;
 
-use 5.14.2;
+use 5.014002;
 use warnings;
+
 use Carp;
 use Zonemaster::Recursor;
 use Zonemaster::Nameserver;
