@@ -4,10 +4,11 @@ package Zonemaster::Test::DNSSEC v1.0.2;
 ### This test module implements DNSSEC tests.
 ###
 
-use 5.14.2;
 use strict;
 use warnings;
 
+use 5.014002;
+
 use Zonemaster;
 use Zonemaster::Util;
 use Zonemaster::Constants qw[:algo :soa];
@@ -124,25 +125,51 @@ sub all {
     my ( $class, $zone ) = @_;
     my @results;
 
-    push @results, $class->dnssec01( $zone ) if Zonemaster->config->should_run('dnssec01');
-    if ( none { $_->tag eq 'NO_DS' } @results ) {
-        push @results, $class->dnssec02( $zone ) if Zonemaster->config->should_run('dnssec02');
+    if ( Zonemaster->config->should_run('dnssec01') ) {
+        push @results, $class->dnssec01( $zone );
     }
-    push @results, $class->dnssec03( $zone ) if Zonemaster->config->should_run('dnssec03');
-    push @results, $class->dnssec04( $zone ) if Zonemaster->config->should_run('dnssec04');
-    push @results, $class->dnssec05( $zone ) if Zonemaster->config->should_run('dnssec05');
-    push @results, $class->dnssec07( $zone ) if Zonemaster->config->should_run('dnssec07');
+
+    if ( none { $_->tag eq 'NO_DS' } @results ) {
+        if ( Zonemaster->config->should_run('dnssec02') ) {
+            push @results, $class->dnssec02( $zone );
+        }
+    }
+
+    if ( Zonemaster->config->should_run('dnssec03') ) {
+        push @results, $class->dnssec03( $zone );
+    }
+    if ( Zonemaster->config->should_run('dnssec04') ) {
+        push @results, $class->dnssec04( $zone );
+    }
+    if ( Zonemaster->config->should_run('dnssec05') ) {
+        push @results, $class->dnssec05( $zone );
+    }
+    if ( Zonemaster->config->should_run('dnssec07') ) {
+        push @results, $class->dnssec07( $zone );
+    }
+
     if ( grep { $_->tag eq q{DNSKEY_BUT_NOT_DS} or $_->tag eq q{DNSKEY_AND_DS} } @results ) {
-        push @results, $class->dnssec06( $zone ) if Zonemaster->config->should_run('dnssec06');
+        if ( Zonemaster->config->should_run('dnssec06') ) {
+            push @results, $class->dnssec06( $zone );
+        }
     }
     else {
         push @results,
           info( ADDITIONAL_DNSKEY_SKIPPED => {} );
     }
-    push @results, $class->dnssec08( $zone ) if Zonemaster->config->should_run('dnssec08');
-    push @results, $class->dnssec09( $zone ) if Zonemaster->config->should_run('dnssec09');
-    push @results, $class->dnssec10( $zone ) if Zonemaster->config->should_run('dnssec10');
-    push @results, $class->dnssec11( $zone ) if Zonemaster->config->should_run('dnssec11');
+
+    if ( Zonemaster->config->should_run('dnssec08') ) {
+        push @results, $class->dnssec08( $zone );
+    }
+    if ( Zonemaster->config->should_run('dnssec09') ) {
+        push @results, $class->dnssec09( $zone );
+    }
+    if ( Zonemaster->config->should_run('dnssec10') ) {
+        push @results, $class->dnssec10( $zone );
+    }
+    if ( Zonemaster->config->should_run('dnssec11') ) {
+        push @results, $class->dnssec11( $zone );
+    }
 
     return @results;
 } ## end sub all
