@@ -1,4 +1,4 @@
-package Zonemaster::Test::Delegation v1.0.1;
+package Zonemaster::Test::Delegation v1.0.3;
 
 use strict;
 use warnings;
@@ -70,6 +70,7 @@ sub metadata {
               IS_NOT_AUTHORITATIVE
               IPV4_DISABLED
               IPV6_DISABLED
+              ARE_AUTHORITATIVE
               )
         ],
         delegation05 => [
@@ -113,14 +114,14 @@ sub translation {
         "EXTRA_NAME_PARENT"    => "Parent has nameserver(s) not listed at the child ({extra}).",
         "NOT_ENOUGH_NS_GLUE"   => "Parent does not list enough nameservers ({glue}). Lower limit set to {minimum}.",
         "NOT_ENOUGH_NS"        => "Child does not list enough nameservers ({ns}). Lower limit set to {minimum}.",
-        "ARE_AUTHORITATIVE"    => "All the nameservers are authoritative.",
+        "ARE_AUTHORITATIVE"    => "All these nameservers are confirmed to be authoritative : {nsset}.",
         "NS_RR_NO_CNAME"       => "No nameserver point to CNAME alias.",
         "SOA_EXISTS"           => "All the nameservers have SOA record.",
         "ENOUGH_NS_TOTAL"      => "Parent and child list enough nameservers ({ns}). Lower limit set to {minimum}.",
         "NOT_ENOUGH_NS_TOTAL" =>
           "Parent and child do not list enough nameservers ({ns}). Lower limit set to {minimum}.",
-        'IPV4_DISABLED' => 'IPv4 is disabled, not sending "{type}" query to {ns}.',
-        'IPV6_DISABLED' => 'IPv6 is disabled, not sending "{type}" query to {ns}.',
+        'IPV4_DISABLED' => 'IPv4 is disabled, not sending "{rrtype}" query to {ns}/{address}.',
+        'IPV6_DISABLED' => 'IPv6 is disabled, not sending "{rrtype}" query to {ns}/{address}.',
     };
 } ## end sub translation
 
@@ -313,6 +314,8 @@ sub delegation04 {
     my ( $class, $zone ) = @_;
     my @results;
     my %nsnames;
+    my @authoritatives;
+    my $query_type = q{SOA};
 
     foreach
       my $local_ns ( @{ Zonemaster::TestMethods->method4( $zone ) }, @{ Zonemaster::TestMethods->method5( $zone ) } )
@@ -322,8 +325,9 @@ sub delegation04 {
             push @results,
               info(
                 IPV6_DISABLED => {
-                    ns   => "$local_ns",
-                    type => q{SOA},
+                    ns      => $local_ns->name->string,
+                    address => $local_ns->address->short,
+                    type    => $query_type,
                 }
               );
             next;
@@ -333,8 +337,9 @@ sub delegation04 {
             push @results,
               info(
                 IPV4_DISABLED => {
-                    ns   => "$local_ns",
-                    type => q{SOA},
+                    ns      => $local_ns->name->string,
+                    address => $local_ns->address->short,
+                    type    => $query_type,
                 }
               );
             next;
@@ -343,15 +348,20 @@ sub delegation04 {
         next if $nsnames{ $local_ns->name };
 
         foreach my $usevc ( 0, 1 ) {
-            my $p = $local_ns->query( $zone->name, q{SOA}, { usevc => $usevc } );
-            if ( not $p or not $p->aa ) {    # Consider non-responsive server non-auth
-                push @results,
-                  info(
-                    IS_NOT_AUTHORITATIVE => {
-                        ns    => $local_ns->name,
-                        proto => $usevc ? q{TCP} : q{UDP},
-                    }
-                  );
+            my $p = $local_ns->query( $zone->name, $query_type, { usevc => $usevc } );
+            if ( $p ) {
+                if ( not $p->aa ) {
+                    push @results,
+                      info(
+                        IS_NOT_AUTHORITATIVE => {
+                            ns    => $local_ns->name,
+                            proto => $usevc ? q{TCP} : q{UDP},
+                        }
+                      );
+                }
+                else {
+                    push @authoritatives, $local_ns->name;
+                }
             }
         }
 
@@ -364,9 +374,15 @@ sub delegation04 {
             or scalar @{ Zonemaster::TestMethods->method5( $zone ) }
         )
         and not scalar @results
+        and scalar @authoritatives
       )
     {
-        push @results, info( ARE_AUTHORITATIVE => {} );
+        push @results,
+          info(
+            ARE_AUTHORITATIVE => {
+                nsset => join( q{,}, @authoritatives ),
+            }
+          );
     }
 
     return @results;
@@ -416,6 +432,7 @@ sub delegation06 {
     my ( $class, $zone ) = @_;
     my @results;
     my %nsnames;
+    my $query_type = q{SOA};
 
     foreach
       my $local_ns ( @{ Zonemaster::TestMethods->method4( $zone ) }, @{ Zonemaster::TestMethods->method5( $zone ) } )
@@ -425,8 +442,9 @@ sub delegation06 {
             push @results,
               info(
                 IPV6_DISABLED => {
-                    ns   => "$local_ns",
-                    type => q{SOA},
+                    ns      => $local_ns->name->string,
+                    address => $local_ns->address->short,
+                    type    => $query_type,
                 }
               );
             next;
@@ -436,8 +454,9 @@ sub delegation06 {
             push @results,
               info(
                 IPV4_DISABLED => {
-                    ns   => "$local_ns",
-                    type => q{SOA},
+                    ns      => $local_ns->name->string,
+                    address => $local_ns->address->short,
+                    type    => $query_type,
                 }
               );
             next;
@@ -445,9 +464,9 @@ sub delegation06 {
 
         next if $nsnames{ $local_ns->name };
 
-        my $p = $local_ns->query( $zone->name, q{SOA} );
+        my $p = $local_ns->query( $zone->name, $query_type );
         if ( $p and $p->rcode eq q{NOERROR} ) {
-            if ( not $p->get_records( q{SOA}, q{answer} ) ) {
+            if ( not $p->get_records( $query_type, q{answer} ) ) {
                 push @results,
                   info(
                     SOA_NOT_EXISTS => {
@@ -540,7 +559,7 @@ sub _max_length_name_for {
     my @chars = q{A} .. q{Z};
 
     my $name = name( $top )->fqdn;
-    $name = '' if $name eq '.';    # Special case for root zone
+    $name = q{} if $name eq q{.};    # Special case for root zone
 
     while ( length( $name ) < $FQDN_MAX_LENGTH - 1 ) {
         my $len = $FQDN_MAX_LENGTH - length( $name ) - 1;
